@@ -1,8 +1,4 @@
-/* $XConsortium: math.c,v 1.17 91/07/25 17:51:34 rws Exp $
- * $MIT: contrib/programs/xcalc/math.c,v 3.2 1999/12/14 18:53:00 gjcoram Exp$
- * $XFree86: xc/programs/xcalc/math.c,v 1.5tsi Exp $ 
- * $XdotOrg: xc/programs/xcalc/math.c,v 1.3 2004/05/23 20:03:49 alanc Exp $
- *
+/*
  *  math.c  -  mathematics functions for a hand calculator under X
  *
  *  Author:    John H. Bradley, University of Pennsylvania
@@ -12,25 +8,15 @@
  *  RPN mode added and port to X11 by Mark Rosenstein, MIT Project Athena
  *
  *  Modified to be a client of the Xt toolkit and the Athena widget set by
- *  Donna Converse, MIT X Consortium.  This is all that remains of the 
+ *  Donna Converse, MIT X Consortium.  This is all that remains of the
  *  original calculator, and it still needs to be rewritten.  The HP
- *  functionality should be separated from the TI functionality. 
+ *  functionality should be separated from the TI functionality.
  *  Beware the HP functions: there are still errors here.
  *
  *  Geoffrey Coram fixed most of the HP mode bugs.
  */
 
-#include <stdio.h>
-#include <X11/Xos.h>
-#include <math.h>
-#include <signal.h>
-#if !defined(IEEE) && defined(SVR4)
-#include <siginfo.h>
-#endif
-#include <setjmp.h>
 #include "xcalc.h"
-#include <errno.h>
-#include <X11/Xlocale.h>
 
 #ifdef _CRAY		/* kludge around Cray STDC compiler */
 double (*log_p)() = log;
@@ -72,29 +58,22 @@ double (*pow_p)() = pow;
 #define True	1
 #define False   0
 
-extern int	rpn;
-extern char 	dispstr[];
-extern void draw();
-extern void ringbell();
-extern void setflag();
-extern void Quit();
-
 #ifndef IEEE
-    jmp_buf env;
+jmp_buf env;
 #endif
 
- 
+
 /* This section is all of the state machine that implements the calculator
  * functions.  Much of it is shared between the infix and rpn modes.
  */
 
-int 	flagINV, flagPAREN, flagM, drgmode;	/* display flags */
+static int flagINV, flagPAREN, flagM, drgmode;	/* display flags */
 
 static double drg2rad=PI/180.0;  /* Conversion factors for trig funcs */
 static double rad2drg=180.0/PI;
 static int entered=1;  /* true if display contains a valid number.
                           if==2, then use 'dnum', rather than the string
-                          stored in the display.  (for accuracy) 
+                          stored in the display.  (for accuracy)
                           if==3, then error occurred, only CLR & AC work */
 /* entered seems to be overloaded - dmc */
 static int lift_enabled = 0;	/* for rpn mode only */
@@ -125,15 +104,12 @@ static int    priority(int op);
 
 /*
  * The following is to deal with the unfortunate assumption that if errno
- * is non-zero then an error has occurred.  On some systems (e.g. Ultrix), 
+ * is non-zero then an error has occurred.  On some systems (e.g. Ultrix),
  * sscanf will call lower level routines that will set errno.
  */
 
 static void
-parse_double (src, fmt, dp)
-    char *src;
-    char *fmt;
-    double *dp;
+parse_double (const char *src, const char *fmt, double *dp)
 {
     int olderrno = errno;
 
@@ -144,11 +120,10 @@ parse_double (src, fmt, dp)
 
 
 /*********************************/
-int pre_op(keynum)
-     int keynum;
+int pre_op(int keynum)
 {
     if (keynum==-1) return(0);
- 
+
     errno = 0;			/* for non-IEEE machines */
 
     if ( (entered==3) && !(keynum==kCLR || keynum==kOFF)) {
@@ -168,99 +143,44 @@ int pre_op(keynum)
 
 /* cannot assign result of setjmp under ANSI C, use global instead */
 static volatile int SignalKind;
-static volatile int SignalCode;
 
-void fail_op()
+void fail_op(void)
 {
     if (SignalKind == SIGFPE)
-    switch (SignalCode) {
-#ifdef SVR4
-      case FPE_INTDIV:		/* integer divide by zero */
-      case FPE_FLTDIV:		/* floating point divide by zero */
-	strcpy(dispstr, "divide by 0");
-	break;
-      case FPE_INTOVF:		/* integer overflow */
-      case FPE_FLTOVF:		/* floating point overflow */
-	strcpy(dispstr, "overflow");
-	break;
-      case FPE_FLTUND:		/* floating point underflow */
-	strcpy(dispstr, "underflow");
-	break;
-      case FPE_FLTRES:		/* floating point inexact result */
-	strcpy(dispstr, "inexact result");
-	break;
-      case FPE_FLTINV:		/* invalid floating point operation */
-	strcpy(dispstr, "invalid op");
-	break;
-      case FPE_FLTSUB:		/* subscript out of range */
-	strcpy(dispstr, "out of range");
-	break;
-
-#endif /*SVR4*/
-
-#ifdef FPE_FLTDIV_TRAP
-      case FPE_FLTDIV_TRAP:  strcpy(dispstr,"div by zero"); break;
-#endif
-#ifdef FPE_FLTDIV_FAULT
-           case FPE_FLTDIV_FAULT: strcpy(dispstr,"div by zero"); break;
-#endif
-#ifdef FPE_FLTOVF_TRAP
-           case FPE_FLTOVF_TRAP:  strcpy(dispstr,"overflow"); break;
-#endif
-#ifdef FPE_FLTOVF_FAULT
-           case FPE_FLTOVF_FAULT: strcpy(dispstr,"overflow"); break;
-#endif
-#ifdef FPE_FLTUND_TRAP
-           case FPE_FLTUND_TRAP:  strcpy(dispstr,"underflow"); break;
-#endif
-#ifdef FPE_FLTUND_FAULT
-           case FPE_FLTUND_FAULT: strcpy(dispstr,"underflow"); break;
-#endif
-           default:               strcpy(dispstr,"error");
-    }
-    else 
-	if (SignalKind == SIGILL)
-	    strcpy(dispstr, "illegal operand");
+	strcpy(dispstr, "math error");
+    else if (SignalKind == SIGILL)
+	strcpy(dispstr, "illegal operand");
 
     entered=3;
     DrawDisplay();
     return;
 }
 
-
-/* keep SVR4 compiler from complaining about scope of arg declaration below */
-typedef struct sigcontext * sigcontextstructp;
 /*ARGSUSED*/
-signal_t fperr(sig,code,scp)
-  int sig,code;
-  sigcontextstructp scp;
+signal_t fperr(int sig)
 {
 #if defined(SYSV) || defined(SVR4) || defined(linux)
-    signal(SIGFPE,(signal_t (*)())fperr);
+    signal(SIGFPE, fperr);
 #endif
     SignalKind = sig;
-    SignalCode = code;
     longjmp(env,1);
 }
 
 /* for VAX BSD4.3 */
 /*ARGSUSED*/
-signal_t illerr(sig,code,scp)
-  int sig,code;
-  sigcontextstructp scp;
+signal_t illerr(int sig)
 {
     /* not reset when caught? */
-    signal(SIGILL,(signal_t (*)())illerr);
+    signal(SIGILL, illerr);
 
     SignalKind = sig;
-    SignalCode = code;
     longjmp(env,1);
 }
 
 #endif	/* not IEEE */
 
 
-void post_op()
+void post_op(void)
 {
 #ifdef DEBUG
     showstack("\0");
@@ -283,7 +203,7 @@ DrawDisplay(void)
         char *estr = index(dispstr,'e');  /* search for exponent part */
         if (!estr) dispstr[12]='\0';      /* no exp, just trunc. */
         else {
-            if ((int) strlen(estr) <= 4) 
+            if ((int) strlen(estr) <= 4)
                 sprintf(tmp,"%.8s",dispstr); /* leftmost 8 chars */
             else
                 sprintf(tmp,"%.7s",dispstr); /* leftmost 7 chars */
@@ -302,8 +222,7 @@ DrawDisplay(void)
 
 /*-------------------------------------------------------------------------*/
 void
-numeric(keynum)
-     int keynum;
+numeric(int keynum)
 {
     char	st[2];
     int		cell = 0;
@@ -361,7 +280,7 @@ numeric(keynum)
   }
   if ((int) strlen(dispstr) >= MAXDISP)
     return;
-    
+
     switch (keynum){
       case kONE:	st[0] = '1'; break;
       case kTWO:	st[0] = '2'; break;
@@ -409,7 +328,7 @@ bkspf(void)
 #else
 	  if (dispstr[strlen(dispstr)-1] == '.')
              Dpoint=0;
-#endif	  
+#endif
 	  dispstr[strlen(dispstr)-1] = 0;
       }
       if (strlen(dispstr) == 0) {
@@ -525,7 +444,7 @@ twoop(int keynum)
     PushOp(keynum);		/* with the new one */
     return;
   }
-  
+
   if (entered==1)
     parse_double(dispstr,"%lf",&dnum);
 
@@ -544,9 +463,9 @@ twoop(int keynum)
 
     /* now, if the current op (keynum) is of
        higher priority than the lastop, the current
-       op and number are just pushed on top 
+       op and number are just pushed on top
        Priorities:  (Y^X) > *,/ > +,- */
-    
+
     if (priority(keynum) > priority(lastop)) {
       PushNum(dnum);
       PushOp(lastop);
@@ -571,8 +490,8 @@ twoop(int keynum)
   else { /* op stack is empty, push op and num */
     PushOp(keynum);
     PushNum(dnum);
-  } 
-}                      
+  }
+}
 
 /* Two operand functions for rpn calc */
 void
@@ -664,7 +583,7 @@ equf(void)
   sprintf(dispstr,"%.8g",dnum);
   DrawDisplay();
 }
-        
+
 void
 lparf(void)
 {
@@ -699,7 +618,7 @@ rparf(void)
 
   if (!flagPAREN)
     return;
-  
+
   clrdisp++;
   Dpoint=exponent=0;
 
@@ -750,7 +669,7 @@ drgf(void)
     flagINV=0;
     sprintf(dispstr,"%.8g",dnum);
   }
-                         
+
   flagINV=0;
   drgmode = (drgmode + 1) % 3;
   switch (drgmode) {
@@ -831,12 +750,12 @@ oneop(int keynum)
 		 entered=3;
 		 break;
 	       }
-	       i=(int) (floor(dnum));
-	       for (j=1,dnum=1.0; j<=i; j++) 
+	       dtmp = floor(dnum); i = dtmp;
+	       for (j=1,dnum=1.0; j<=i; j++)
 		 dnum*=(float) j;
 	       break;
   }
-  
+
   if (entered==3) {  /* error */
     DrawDisplay();
     return;
@@ -877,8 +796,7 @@ static int numsp;
 
 /*******/
 static void
-PushOp(op)
-   int op;
+PushOp(int op)
 /*******/
 {
   if (opsp==STACKMAX) {strcpy(dispstr,"stack error");  entered=3;}
@@ -908,8 +826,7 @@ isopempty(void)
 
 #ifdef DEBUG
 static void
-showstack(string)
-    char	*string;
+showstack(char *string)
 {
     fprintf(stderr, "%s: %lf %lf %lf\n", string, numstack[0], numstack[1],
 	    numstack[2]);
@@ -918,8 +835,7 @@ showstack(string)
 
 /*******/
 static void
-PushNum(num)
- double num;
+PushNum(double num)
 /*******/
 {
   if (rpn) {
@@ -990,8 +906,7 @@ ClearStacks(void)
 
 /*******/
 static int
-priority(op)
-         int op;
+priority(int op)
 /*******/
 {
     switch (op) {
